#!/usr/bin/perl
=head1

=head1 NAME
sendsms.pl - SMS ueber SMSCreator versenden

=head1 Motto

Keep it small, fast and simple

=head1 DESCRIPTION

Mit diesem Script koennen SMS ueber SMSCreator versendet werden.

=head1 TODO

- Make output a little bit nicer

=cut

#use strict;
use Data::Dump qw(dump);
use SOAP::Lite trace => 'all';


use constant SERIENNUMMER     => 'test'; # SMSCreator Serial 
use constant PASSWORT         => 'test'; # SMSCreator Password 


my ($rv, $retObj) = &sendsms("Testnachricht","2008-11-26T12:00:33", "Standard","Absender",split("\n","0049171123456789\n0049171987654321"));

print "$rv: $rv \nLoginStatusCode:" . $retObj->{"StatusCode"} ." \nAnnahmeStatus:" . $retObj->{"Value"}->{"Status"} . " \nJobId: " . $retObj->{"Value"}->{"JobId"} . "\n";
exit;

=item B<sendsms>(I<string>, I<string>, I<array>, I<string>, I<string>)

=over

Versendet eine SMS per SOAP an Netxp. Als Parameter werden erwartet:
  - Nachricht        String nicht laenger als 160 Zeichen. Ist die
                     Nachricht laenger als 160 Zeichen, so werden
                     nur die ersten 160 Zeichen genommen
  - Sendezeitpunkt   dateTime
  - Empfaenger       Array
    <SendSMS xmlns="http://www.smscreator.de/gateway">
      <User>string</User>
      <Password>string</Password>
      <Caption>string</Caption>
      <Sender>string</Sender>
      <Recipient>
        <string>string</string>
        <string>string</string>
      </Recipient>
      <SMSText>string</SMSText>
      <SmsTyp>Flash or Standard or StandardDeliveryNotification or StandardLong or HighQuality or HighQualityLong or PSTNFixedLine</SmsTyp>
      <SendDate>dateTime</SendDate>
    </SendSMS>


Rueckgabe:
      <SendSMSResult>
        <StatusCode>None or Ok or InvalidUser or AccountLocked or IPLock or DatabaseError</StatusCode>
        <Value>
          <Status>None or Ok or NoTextFound or NoRecipientFound or SMSTypeError or LoginError or UnknowError or DatabaseError</Status>
          <JobId>int</JobId>
        </Value>
      </SendSMSResult>
    </SendSMSResponse>

=back

=cut

use constant URI              => 'http://www.smscreator.de/gateway'; # URI SMSCreator hier muss nichts eingstellt werden

sub sendsms
{
  my ($msg, $schedule, $smsType,$sender,@clis) = @_;

  $msg = substr($msg, 0, 160);

  my $soap = SOAP::Lite
     -> uri(URI)
     -> proxy('http://www.smscreator.de/gateway/Send.asmx') 
     -> encoding('utf-8')
     -> on_action(sub{sprintf '%s/%s', @_ }) 
     ;

  my $User     = SOAP::Data->name('User'      => SERIENNUMMER)->type('');
  my $Pw       = SOAP::Data->name('Password'  => PASSWORT)->type('');
  my $Caption  = SOAP::Data->name('Caption'   => "Caption")->type('');
  my $Sender   = SOAP::Data->name('Sender'    =>  "$sender")->type('');
  my $Empf     = array_string("Recipient", @clis);
  my $Text     = SOAP::Data->name('SMSText'   => "$msg")->type('');
  my $SMSTyp   = SOAP::Data->name('SmsTyp'    => "$smsType")->type('');
  my $SendDate = SOAP::Data->name('SendDate'  => "$schedule")->type('');

# ber denn direkt call funktoniert es bei lterne versionen von SOAP::Lite nicht
#  my $result = $soap->SendSMS($User,$Pw, $Caption, $Sender,$Empf, $Text, $SMSTyp, $SendDate);
  my $result = $soap->call (SOAP::Data->name ('SendSMS')->attr ({xmlns => URI}),
	($User,$Pw, $Caption, $Sender,$Empf, $Text, $SMSTyp, $SendDate));

  unless ($result->fault)
  {
    my $rv = $result->result();
    return(0,$rv);
  }
  else
  {
    my $str = join ', ', 
    $result->faultcode, 
    $result->faultstring, 
    $result->faultdetail;
    return(-1, $str);
  }
}


sub array_string  {
  my ($name, @data) = @_;
  my $soap_data = SOAP::Data->value(SOAP::Data->name("string" => @data)->type(""));
  $soap_data->type('ArrayOfString');
  return SOAP::Data->name($name, \$soap_data);
}
